/*******************************************************************************
 *
 * blueMarine - open source photo workflow
 * =======================================
 *
 * Copyright (C) 2003-2009 by Fabrizio Giudici
 * Project home page: http://bluemarine.tidalwave.it
 *
 *******************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 *
 *******************************************************************************
 *
 * $Id$
 *
 ******************************************************************************/
package it.tidalwave.metadata.iptc.vocabularies;

import javax.annotation.Nonnull;
import org.openide.util.Lookup;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 ******************************************************************************/
public interface IPTCVocabularyFactory 
  {
    @Nonnull
    public IPTCVocabulary getGenreVocabulary();
    
    @Nonnull
    public IPTCVocabulary getProviderVocabulary();
    
    @Nonnull
    public IPTCVocabulary getSceneVocabulary();
    
    @Nonnull
    public IPTCVocabulary getSubjectCodeVocabulary();
    
    @Nonnull
    public IPTCVocabulary getCopyrightStatusVocabulary();
    
    public static class Locator
      {
        private Locator()
          {
          }
        
        @Nonnull
        public static IPTCVocabularyFactory findIPTCVocabularyFactory()
          {
            final IPTCVocabularyFactory vocabularyFactory = Lookup.getDefault().lookup(IPTCVocabularyFactory.class);

            if (vocabularyFactory == null)
              {
                throw new RuntimeException("IPTCVocabularyFactory not found");
              }

            return vocabularyFactory;
          }
      }
  }
