/*******************************************************************************
 *
 * blueMarine - open source photo workflow
 * =======================================
 *
 * Copyright (C) 2003-2009 by Fabrizio Giudici
 * Project home page: http://bluemarine.tidalwave.it
 *
 *******************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 *
 *******************************************************************************
 *
 * $Id$
 *
 ******************************************************************************/
package it.tidalwave.metadata.iptc.vocabularies.impl;

import javax.annotation.Nonnull;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;
import java.io.Serializable;
import it.tidalwave.metadata.iptc.vocabularies.IPTCVocabulary;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 ******************************************************************************/
public class IPTCVocabularyImpl extends IPTCVocabulary implements Serializable
  {
    final public static class EntryImpl implements Entry, Serializable
      {
        private static final long serialVersionUID = 3454508723874508971L;
        
        private final String formalName;
        private final String name;
        private final String explanation;
        private final String changeComment;
        private final String changeVersion;
        private final String firstVersion;
        private final String deprecatedVersion;

        protected EntryImpl (@Nonnull final String formalName,
                             @Nonnull final String name,
                             @Nonnull final String explanation,
                             @Nonnull final String changeComment,
                             @Nonnull final String changeVersion,
                             @Nonnull final String firstVersion,
                             @Nonnull final String deprecatedVersion)
          {
            this.formalName = formalName;
            this.name = name;
            this.explanation = explanation;
            this.changeComment = changeComment;
            this.changeVersion = changeVersion;
            this.firstVersion = firstVersion;
            this.deprecatedVersion = deprecatedVersion;
          }
        
        @Override
        @Nonnull
        public String toString()
          {
            return "Entry[" + name + "]";    
          }

        @Nonnull
        public String getChangeComment() 
          {
            return changeComment;
          }

        @Nonnull
        public String getChangeVersion() 
          {
            return changeVersion;
          }

        @Nonnull
        public String getDeprecatedVersion() 
          {
            return deprecatedVersion;
          }

        @Nonnull
        public String getExplanation()  
          {
            return explanation;
          }

        @Nonnull
        public String getFirstVersion() 
          {
            return firstVersion;
          }

        @Nonnull
        public String getFormalName()  
          {
            return formalName;
          }

        @Nonnull
        public String getName() 
          {
            return name;
          } 
      }

    private static final long serialVersionUID = 7034968723874508971L;

    @Nonnull
    public List<Entry> internalGetEntries() 
      {
        return sortedEntries;
      }

    protected void add (@Nonnull final Entry entry)
      {
        sortedEntries.add(entry);
      }

    @edu.umd.cs.findbugs.annotations.SuppressWarnings("SIC_INNER_SHOULD_BE_STATIC_ANON")
    protected void prepare() 
      {
        Collections.sort(sortedEntries, new Comparator<Entry>() 
          {
            public int compare (@Nonnull final Entry e1, @Nonnull final Entry e2)
              {
                return e1.getName().compareTo(e2.getName());
              }
          });
      }
  }
